%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% (c) Faia, Lechthaler, Merkl    %%%
%%%     December, 2012             %%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

var a u r w pir eta n fr Y pai pz Co rgm QO QI cutI cutO int g;
parameters sub beta h f sd epselon rho rhoa rhog phi const gamma sigma i b ALFAI ALFAPAI ALFAY ALFAN paiss ass Yss gss intss rgmss nss strike;
varexo uu ua ug;

%%%%%%%%%%%%%%%%%%%%%
%%%  parameter values
%%%%%%%%%%%%%%%%%%%%%

beta=0.99;                          % discount rate
epselon=10;                         % elasticity of substitution
sigma=2;                            % Utility function parameter
sub=0;                              


% labor market
h=0.4;                   % hiring cost
f=2.4;                           % firing cost
gamma=0.5;           % workers' bargaining power
b=0.65;                            % unemployment benefits

% shock distribution 
sd=0.5304925;                            % scaling parameter of shock distribution
const=0;                    % expected value of shock distribution
strike=0.2779288;

% price setting
teta=0.75;                          % Calvo parameter
phi=(epselon)*teta/((1-teta)*(1-beta*teta));   % cost of price adjustment; set in such a way that the PC corresponds to Calvo

% Autocorrelation of shocks
rho=0.0;                            % money shock
rhoa=0.95;                          % productivity shock
rhog=0.9;                           % government expenditure shock

% TAYLOR RULE CALIBRATION
ALFAI=0.0;                          % degree of interest rate inertia in Taylor rule
ALFAPAI=1.5;                        % coefficient on inflation gap
ALFAY=0.125;                        % coefficient on output gap
ALFAN=0;                            % coefficient on employment


%%%%%%%%%%%%%%%%%%%%%%%
%%% steady state values
%%%%%%%%%%%%%%%%%%%%%%%

pzss=((epselon-1)/epselon);         % marginal cost
ass=1;                           % productivity 
paiss=1;                            % inflation

frss=0.02;                          % firing rate
etass=0.2;                          % hiring rate
nss=etass/(frss+etass);             % employment

pirss= -0.324701;                   % expected profits
cutOss= -0.735419;                   % hiring threshold
cutIss= 2.06458;          % firing threshold
QSS=-0.0530704;                 % expected value of operating cost for an insider
QOSS=-1.3273;               % expected value of operating cost for an insider
wss=0.913964;                        % wage

Yss=nss*ass;                        % production

gss=0.25*Yss;                       % government spending
rgmss=1;                            % intereste rate shock

intss=1/beta;
Css=Yss-nss*frss*f*ass-(1-nss)*etass*h*ass-nss*(1-frss)*(QSS+const)*ass-(1-nss)*etass*(QOSS+const)*ass-gss;
rss=intss-1;

model;
w=gamma*(a*pz+ass*strike)+(1-gamma)*ass*b;
pir=(1-fr)*((a*pz-w)-ass*QI-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1))-fr*f*ass;
eta=1/(1+exp((-1)*(pz*a-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)-h*ass)/(ass*sd)));
fr=1-1/(1+exp((-1)*((pz*a-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)+f*ass)/(ass*sd))));
n=(1-fr-eta)*n(-1)+eta;
cutI*ass=(a*pz-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)+f*ass);
QI=(cutI-(cutI/(1+exp(cutI/(sd))))-sd*log(1+exp(cutI/(sd))))/(1-fr);
cutO*ass=pz*a-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)-h*ass;
QO=(cutO-(cutO/(1+exp(cutO/(sd))))-sd*log(1+exp(cutO/(sd))))/eta;
Y=n*a;
int=(1+r)*pai(+1);
(1-epselon)*Co^(-sigma)+epselon*Co^(-sigma)*pz*(1-sub)-Co^(-sigma)*phi*(pai-paiss)*pai+Co(+1)^(-sigma)*phi*beta*(pai(+1)-paiss)*(Y(+1)/Y)*pai(+1)=0;
Co(+1)^(sigma)=Co^(sigma)*beta*(1+r);
Co=Y-n(-1)*fr*f*ass-(1-n(-1))*eta*h*ass-n(-1)*(1-fr)*(QI+const)*ass-(1-n(-1))*eta*(QO+const)*ass-phi/2*(pai-paiss)^2*Y-g;
rgm=rgmss^(1-rho)*rgm(-1)^rho*exp(-uu);
a=ass^(1-rhoa)*a(-1)^rhoa*exp(ua);
g/gss=(g(-1)/gss)^(rhog)*exp(ug);
u=1-n;
pai=1;
end;

initval;
a=ass;
pz=pzss;
cutI= 		 cutIss;
cutO=        cutOss;
eta= 		 etass;
fr=  		 frss;
n=   		 nss;
pir= 		 pirss;
QI=   		 QSS;
QO=QOSS;
w=   		 wss;
pai=paiss;
Y=Yss;
Co=Css;
r=rss;
rgm=1;
int=intss;
g=gss;
end;

shocks;
var ug; stderr 0.0074;  
end;

stoch_simul(IRF=100,hp_filter=1600);

output_path_stablePi  = 100*(Y_ug/Yss);
w_path_stablePi       = 100*(w_ug/wss);
a_path_stablePi       = 100*(a_ug/ass);
n_path_stablePi       = 100*(n_ug/nss);
pi_path_stablePi      = 100*((1+pai_ug).^4-ones(size(100,1),1));
mc_path_stablePi      = 100*(pz_ug/pzss);
eta_path_stablePi     = 100*(eta_ug/etass);
fr_path_stablePi      = 100* (fr_ug/frss);
Co_path_stablePi      = 100*(Co_ug/Css);
cutI_path_stablePi    = 100*(cutI_ug/cutIss);
cutO_path_stablePi    = 100*(cutO_ug/cutOss);
pir_path_stablePi     = 100*(pir_ug);

close all;

save gshock_stablePi output_path_stablePi w_path_stablePi a_path_stablePi n_path_stablePi pi_path_stablePi mc_path_stablePi fr_path_stablePi eta_path_stablePi Co_path_stablePi cutI_path_stablePi cutO_path_stablePi pir_path_stablePi 
