%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Unemployment and GDP Autocorrelations
% 
% biljanovska@gmail.com
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% loading data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load gdpunemp;

data = gdpunemp;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% taking logs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data_log=log(data);
gdpfr=data_log(:,1:1);
gdpde=data_log(53:end,2:2);
gdpit=data_log(13:end,3:3);
gdpes=data_log(69:end,4:4);
unemployment=data_log(11:end,5:end);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% HP filter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gdpfr_hp=hp_filter(gdpfr,1600);
gdpde_hp=hp_filter(gdpde,1600);
gdpit_hp=hp_filter(gdpit,1600);
gdpes_hp=hp_filter(gdpes,1600);
unemployment_hp=hp_filter(unemployment,1600);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Trend gap
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gdpfr_gap=gdpfr-gdpfr_hp;
gdpde_gap=gdpde-gdpde_hp;
gdpit_gap=gdpit-gdpit_hp;
gdpes_gap=gdpes-gdpes_hp;
unemployment_gap=unemployment-unemployment_hp;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculating p-th order 
% autocorrelation coefficients
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
matrix=[gdpfr_gap(69:end,:),gdpde_gap(17:end,:),gdpit_gap(57:end,:),gdpes_gap,unemployment(59:end,:)];
p_max=5; %max number of autocorrelations
auto_corr=zeros(p_max,size(matrix,2));

for i=1:size(matrix,2); %outer loop over the variables
for p=1:p_max % inner loop:  up to 12 quarters autocorrelation
temp_t0=matrix(1:end-p,i);
temp_p=matrix(1+p:end,i);
auto_corr(p,i)=corr(temp_t0,temp_p);
end  %end inner loop
end  % end outer loop

