%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% (c) Faia, Lechthaler, Merkl    %%%
%%%     November 24, 2012          %%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


maxit=100000;

ii = 1;

for firing = [2.4]

var a u r w pir eta n fr Y pai pz Co rgm QO QI cutI cutO int g X El;
parameters sub rhog beta h f sd epselon rho rhoa phi const gamma sigma i b ALFAI ALFAPAI ALFAY ALFAN paiss ass Yss gss intss rgmss nss strike intssv;
varexo uu ua ug;

% reading in the calibration matrix

load steady_state_matrix.mat 

%%%%%%%%%%%%%%%%%%%%%
%%%  parameter values
%%%%%%%%%%%%%%%%%%%%%

beta=0.99;                          % discount rate
epselon=10;                         % elasticity of substitution
sigma=2;                            % Utility function parameter

% labor market
h=hiringCosts;                   % hiring cost
f=firingCosts;                           % firing cost
gamma=bargainingPower;           % workers' bargaining power
b=ub;                            % unemployment benefits

% shock distribution 
sd=s;                            % scaling parameter of shock distribution
const=consta;                    % expected value of shock distribution
strike=strikeCost;

% price setting
teta=0.75;                          % Calvo parameter
phi=(epselon-1)*teta/((1-teta)*(1-beta*teta));   % cost of price adjustment; set in such a way that the PC corresponds to Calvo

% Autocorrelation of shocks
rho=0.0;                            % money shock
rhoa=0.95;                          % productivity shock
rhog=0.9;                           % government expenditure shock

% TAYLOR RULE CALIBRATION
ALFAPAI=1.5;                        % coefficient on inflation gap


%%%%%%%%%%%%%%%%%%%%%%%
%%% steady state values
%%%%%%%%%%%%%%%%%%%%%%%

pzss=((epselon-1)/epselon);         % marginal cost
ass=1;                           % productivity 
paiss=1;                            % inflation
sub=1/epselon;                      % subsidiy to get rid of monopolistic distortion

frss=0.02;                          % firing rate
etass=0.2;                          % hiring rate
nss=etass/(frss+etass);             % employment

pirss=Eprofit;                   % expected profits
cutOss=hiringThreshold;          % hiring threshold
cutIss=firingThreshold;          % firing threshold
QSS=EepsInsider;                 % expected value of operating cost for an insider
QOSS=EepsOutsider;               % expected value of operating cost for an insider
wss=wage;                        % wage

Yss=nss*ass;                        % production

gss=0.25*Yss;                       % government spending
rgmss=1;                            % intereste rate shock

intss=1/beta;
Css=Yss-nss*frss*f*ass-(1-nss)*etass*h*ass-nss*(1-frss)*(QSS+const)*ass-(1-nss)*etass*(QOSS+const)*ass;
rss=intss-1;
intssv=intss;

model;
w=gamma*(a*pz+ass*strike)+(1-gamma)*ass*b;
pir=(1-fr)*((a*pz-w)-ass*QI-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1))-fr*f*ass;
eta=1/(1+exp((-1)*(pz*a-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)-h*ass)/(ass*sd)));
fr=1-1/(1+exp((-1)*((pz*a-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)+f*ass)/(ass*sd))));
n=(1-fr-eta)*n(-1)+eta;
cutI*ass=(a*pz-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)+f*ass);
QI=(cutI-(cutI/(1+exp(cutI/(sd))))-sd*log(1+exp(cutI/(sd))))/(1-fr);
cutO*ass=pz*a-w-ass*const+beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*pir(+1)-h*ass;
QO=(cutO-(cutO/(1+exp(cutO/(sd))))-sd*log(1+exp(cutO/(sd))))/eta;
Y=n*a;
int=(1+r)*pai(+1);
(1-epselon)*Co^(-sigma)+epselon*Co^(-sigma)*pz-Co^(-sigma)*phi*(pai-paiss)*pai+Co(+1)^(-sigma)*phi*beta*(pai(+1)-paiss)*(Y(+1)/Y)*pai(+1)=0;
Co(+1)^(sigma)=Co^(sigma)*beta*(1+r);
Co=Y-n(-1)*fr*f*ass-(1-n(-1))*eta*h*ass-n(-1)*(1-fr)*(QI+const)*ass-(1-n(-1))*eta*(QO+const)*ass-phi/2*(pai-paiss)^2*Y-g;
rgm=rgmss^(1-rho)*rgm(-1)^rho*exp(-uu);
a=ass^(1-rhoa)*a(-1)^rhoa*exp(ua);
g/gss=(g(-1)/gss)^(rhog)*exp(ug);
u=1-n;
X=pai^4-1;
El=a(+1)/(beta*((Co(+1)^(-sigma))/(Co^(-sigma)))*(cutO(+1)-QO(+1)));
int/intssv=pai^ALFAPAI;
end;

initval;
a=ass;
pz=pzss;
cutI= 		 cutIss;
cutO=        cutOss;
eta= 		 etass;
fr=  		 frss;
n=   		 nss;
pir= 		 pirss;
QI=   		 QSS;
QO=QOSS;
w=   		 wss;
pai=paiss;
Y=Yss;
Co=Css;
r=rss;
rgm=1;
int=intss;
g=gss;
El= 1.7066;
end;

shocks;
var ug; stderr 0.0074;
end;

steady;
check;

stoch_simul(irf=0,order=1,hp_filter=1600);

u_simul(:,ii)=sqrt((oo_.var(2,2)))/oo_.mean(2);
eta_simul(:,ii)=sqrt((oo_.var(6,6)))/oo_.mean(6);
fr_simul(:,ii)=sqrt((oo_.var(8,8)))/oo_.mean(8);
Output_simul(:,ii)=sqrt((oo_.var(9,9)))/oo_.mean(9);
AnnInf_simul(:,ii)=(oo_.var(20,20));

ii = ii +1;

end

Output_vol=sqrt((oo_.var(9,9)))/oo_.mean(9)*100
u_vol=sqrt((oo_.var(2,2)))/oo_.mean(2)*100
eta_vol=sqrt((oo_.var(6,6)))/oo_.mean(6)*100
fr_vol=sqrt((oo_.var(8,8)))/oo_.mean(8)*100

Output_ac=oo_.autocorr{1,1}(9,9)
u_ac=oo_.autocorr{1,1}(2,2)

